@@ -43,7 +43,7 @@ class SQLBase:
     sql = SQL(SQlAlchemyORM.__table__)
 
     -----------------------------------------------------------------------------------------------
-    # Read
+    # Read (Examples)
     -----------------------------------------------------------------------------------------------
     - Filter-By         : await sql.filter_by(id=1, name="spongebob")
     - Search-Columns    : await sql.search(["name", "title"], "bob")
@@ -63,8 +63,8 @@ class SQLBase:
 
     def __init__(self, database_url, table):
         """__init__"""
-        self.table = table
-        self.Q = SQLFilters(table)
+        self.table = table.objects
+        self.Q = SQLFilters(table.objects)
         self.database = Database(database_url)
 
     async def find(
